local Addon = {name = "ShowTTCPrice", version = 17, SV_version = 3}

local DropdownPrices = {None = "None", Average = "Avg", Suggested = "SuggestedPrice", Min = "Min", Max = "Max"}
local CoinIcon = "|t16:16:EsoUI/Art/currency/currency_gold.dds|t"
local Settings = {}
local Colors = {Orange = "|cFCBA03", Dark_Orange = "|cFC8403", White = "|cFFFFFF", Green = "|c24FC03", Dark_Green = "|c20B00B", Pink = "|cff9d9d"}
local TogglePriceButtons = {}
local GuildStoreHook1 = false
local GuildStoreHook2 = false
local SV_default = {
	--general
    Enabled = true,
    EnableToggleButton = false,
    PreferredPrice = "Suggested",
    PriceToShow = "Stack and Unit",
    RoundNumbers = true,
	--filters
    IgnoreBoundItems = true,
    IgnoreTrash = true,
    IgnoreBelowVendor = true,
	--
    HighlightReq = false,
    DesiredValue = 5000,
	--
    MinimumReq = false,
    RequiredValue = 25,
	--guild store
    EnableInGuildStore = true,
    GuildStoreInfoToShow = "Profit",
	--
    HighlightRiskyDeals = true,
    RiskyDealsListingsCount = 10,
	--AwesomeGuildStore
    EnableAwesomeGuildStoreIntegration = true,
    EnableDealFilter = true,
    EnableProfitFilter = true,
}

function Addon.SetupSettings()
	local LAM = LibAddonMenu2
	if not LAM then return end
	Settings = Addon.SavedVariables
	if Settings.PriceToShow == "Both" then Settings.PriceToShow = "Stack and Unit" end

	local PanelName = "ShowTTCPrice_Settings"
	local PanelData = {type = "panel", name = "Show TTC Price", displayName = "Show TTC Price", author = "MarioKness", version = tostring(Addon.version), registerForDefaults = true}
	LAM:RegisterAddonPanel(PanelName, PanelData)

	local OptionsData = {
		{
		type = "header", name = "Settings", width = "full"
		},
		{
		type = "checkbox",
		name = "Show toggle button",
		tooltip = "Add a toggle above your inventory that lets you swap between TTC and ESO prices" .. " (same function as " .. Colors.Orange .. "Keybindings > Show TTC Price > Toggle TTC Price|r)" .. "\n\nDefault: " .. tostring(SV_default.EnableToggleButton),
		requiresReload = true,
		getFunc = function() return Settings.EnableToggleButton end,
		setFunc = function(value) Settings.EnableToggleButton = value end,
		default = SV_default.EnableToggleButton
		},
		{
		type = "dropdown",
		name = "Preferred price",
		tooltip = "(None = ESO price)" .. "\n\nDefault: " .. tostring(SV_default.PreferredPrice),
		choices = {"None", "Suggested", "Average", "Min", "Max"},
		getFunc = function() return Settings.PreferredPrice end,
		setFunc = function(choice) Settings.PreferredPrice = choice end,
		default = SV_default.PreferredPrice
		},
		{
		type = "dropdown",
		name = "Price to show",
		choices = {"Stack", "Unit", "Stack and Unit", "Stack (ESO and TTC)", "Unit (ESO and TTC)"},
		tooltip = "Default: " .. tostring(SV_default.PriceToShow),
		getFunc = function() return Settings.PriceToShow end,
		setFunc = function(choice) Settings.PriceToShow = choice end,
		default = SV_default.PriceToShow
		},
		{
		type = "checkbox",
		name = "Round numbers",
		tooltip = "Default: " .. tostring(SV_default.RoundNumbers),
		getFunc = function() return Settings.RoundNumbers end,
		setFunc = function(value) Settings.RoundNumbers = value end,
		default = SV_default.RoundNumbers
		},
		{
		type = "header", name = "Filters", width = "full"
		},
		{
		type = "checkbox",
		name = "Ignore bound items",
		tooltip = "Default: " .. tostring(SV_default.IgnoreBoundItems),
		getFunc = function() return Settings.IgnoreBoundItems end,
		setFunc = function(value) Settings.IgnoreBoundItems = value end,
		default = SV_default.IgnoreBoundItems
		},
		{
		type = "checkbox",
		name = "Ignore items of type 'Trash'",
		tooltip = "Ignore items like Carapace, Daedra Husk, Foul Hide, etc." .. "\n\nDefault: " .. tostring(SV_default.IgnoreTrash),
		getFunc = function() return Settings.IgnoreTrash end,
		setFunc = function(value) Settings.IgnoreTrash = value end,
		default = SV_default.IgnoreTrash
		},
		{
		type = "checkbox",
		name = "Ignore below default sell price",
		tooltip = "Ignore items if their TTC price is less than their ESO price" .. "\n\nDefault: " .. tostring(SV_default.IgnoreBelowVendor),
		getFunc = function() return Settings.IgnoreBelowVendor end,
		setFunc = function(value) Settings.IgnoreBelowVendor = value end,
		default = SV_default.IgnoreBelowVendor
		},
		{
		type = "divider", alpha = 0.5, width = "half"
		},
		{
		type = "checkbox",
		name = "Highlight above value",
		tooltip = Colors.Dark_Green .. "Highlight|r" .. " items if their TTC price is greater than or equal to Desired value" .. "\n\nDefault: " .. tostring(SV_default.HighlightReq),
		getFunc = function() return Settings.HighlightReq end,
		setFunc = function(value) Settings.HighlightReq = value end,
		default = SV_default.HighlightReq
		},
		{
		type = "slider",
		name = "Desired value",
		min = 0, max = 1000000, width = "full",
		tooltip = "Default: " .. tostring(SV_default.DesiredValue),
		getFunc = function() return Settings.DesiredValue end,
		setFunc = function(value) Settings.DesiredValue = value end,
		default = SV_default.DesiredValue
		},
		{
		type = "divider", alpha = 0.5, width = "half"
		},
		{
		type = "checkbox",
		name = "Ignore below value",
		tooltip = "Ignore items if their TTC price is less than Required value" .. "\n\nDefault: " .. tostring(SV_default.MinimumReq),
		getFunc = function() return Settings.MinimumReq end,
		setFunc = function(value) Settings.MinimumReq = value end,
		default = SV_default.MinimumReq
		},
		{
		type = "slider",
		name = "Required value",
		min = 0, max = 1000000, width = "full",
		tooltip = "Default: " .. tostring(SV_default.RequiredValue),
		getFunc = function() return Settings.RequiredValue end,
		setFunc = function(value) Settings.RequiredValue = value end,
		default = SV_default.RequiredValue
		},
		{
		type = "header", name = "Guild Store", width = "full"
		},
		{
		type = "checkbox",
		name = "Enable Guild Store features",
		requiresReload = true,
		tooltip = "Default: " .. tostring(SV_default.EnableInGuildStore),
		getFunc = function() return Settings.EnableInGuildStore end,
		setFunc = function(value) Settings.EnableInGuildStore = value end,
		default = SV_default.EnableInGuildStore
		},
		{
		type = "dropdown",
		name = "Guild Store info to show",
		choices = {"None", "Discount", "Profit"},
		tooltip = "Default: " .. tostring(SV_default.GuildStoreInfoToShow),
		getFunc = function() return Settings.GuildStoreInfoToShow end,
		setFunc = function(choice) Settings.GuildStoreInfoToShow = choice end,
		default = SV_default.GuildStoreInfoToShow
		},
		{
		type = "divider", alpha = 0.5, width = "half"
		},
		{
		type = "checkbox",
		name = "Highlight risky deals",
		tooltip = Colors.Pink .. "Highlight|r" .. " Discount and Profit of items with too few listings" .. "\n\nDefault: " .. tostring(SV_default.HighlightRiskyDeals),
		getFunc = function() return Settings.HighlightRiskyDeals end,
		setFunc = function(value) Settings.HighlightRiskyDeals = value end,
		default = SV_default.HighlightRiskyDeals
		},
		{
		type = "slider",
		name = "Required listings",
		min = 0, max = 1000000, width = "full",
		tooltip = "Number of listings required to consider the item's pricing data attendible" .. "\n\nDefault: " .. tostring(SV_default.RiskyDealsListingsCount),
		getFunc = function() return Settings.RiskyDealsListingsCount end,
		setFunc = function(value) Settings.RiskyDealsListingsCount = value end,
		default = SV_default.RiskyDealsListingsCount
		},
		{
		type = "divider", alpha = 0.5, width = "half"
		},
		{
		type = "checkbox",
		name = "Enable AwesomeGuildStore integration",
		tooltip = "Add Discount and Profit filters to AwesomeGuildStore" .. "\n\nDefault: " .. tostring(SV_default.EnableAwesomeGuildStoreIntegration),
		requiresReload = true,
		getFunc = function() return Settings.EnableAwesomeGuildStoreIntegration end,
		setFunc = function(value) Settings.EnableAwesomeGuildStoreIntegration = value end,
		default = SV_default.EnableAwesomeGuildStoreIntegration
		},
		{
		type = "checkbox",
		name = "Enable Deal Filter",
		requiresReload = true,
		tooltip = "Default: " .. tostring(SV_default.EnableDealFilter),
		getFunc = function() return Settings.EnableDealFilter end,
		setFunc = function(value) Settings.EnableDealFilter = value end,
		default = SV_default.EnableDealFilter
		},
		{
		type = "checkbox",
		name = "Enable Profit Filter",
		requiresReload = true,
		tooltip = "Default: " .. tostring(SV_default.EnableProfitFilter),
		getFunc = function() return Settings.EnableProfitFilter end,
		setFunc = function(value) Settings.EnableProfitFilter = value end,
		default = SV_default.EnableProfitFilter
		},
	}
	LAM:RegisterOptionControls(PanelName, OptionsData)
end

function ShowTTCPrice_TogglePrices()
	Settings.Enabled = not Settings.Enabled
	if Settings.EnableToggleButton == true then
		--change button text
		for i = 1, #TogglePriceButtons do
			if Settings.Enabled then
				TogglePriceButtons[i]:SetText("TTC " .. CoinIcon)
			else
				TogglePriceButtons[i]:SetText("ESO " .. CoinIcon)
			end
		end
	end
	--refresh inventories
	PLAYER_INVENTORY:UpdateList(INVENTORY_BACKPACK)
	PLAYER_INVENTORY:UpdateList(INVENTORY_CRAFT_BAG)
	PLAYER_INVENTORY:UpdateList(INVENTORY_BANK)
	PLAYER_INVENTORY:UpdateList(INVENTORY_HOUSE_BANK)
	PLAYER_INVENTORY:UpdateList(INVENTORY_GUILD_BANK)
end

local function RoundNumber(num, numDecimalPlaces)
  local mult = 10^(numDecimalPlaces or 0)
  return math.floor(num * mult + 0.5) / mult
end

local function FormatNumber(number)
	local i, j, minus, int, fraction = tostring(number):find('([-]?)(%d+)([.]?%d*)')
	int = int:reverse():gsub("(%d%d%d)", "%1,")
	return minus .. int:reverse():gsub("^,", "") .. fraction
end

local function RoundAndFormat(number)
	if Settings.RoundNumbers then number = RoundNumber(number) end
	return FormatNumber(number)
end

local function ShowTTCPrice(control, slot)
	--data and filters
	if Settings.PreferredPrice == "None" or not Settings.Enabled then return end --if enabled
	local ItemData = control.dataEntry.data
    local BagId = ItemData.bagId
    local SlotIndex = ItemData.slotIndex
    local ItemLink =  GetItemLink(BagId, SlotIndex)
	if not ItemLink then return end
	if IsItemLinkBound(ItemLink) and Settings.IgnoreBoundItems then return end --if bound
	local ItemType, SpecializedItemType = GetItemLinkItemType(ItemLink)
	if SpecializedItemType == SPECIALIZED_ITEMTYPE_TRASH and Settings.IgnoreTrash then return end --if trash
	local SellPriceControl = control:GetNamedChild("SellPrice")
	if not SellPriceControl then return end
	local ItemPriceData = TamrielTradeCentrePrice:GetPriceInfo(ItemLink)
	if not ItemPriceData then return end
	local PreferredPrice = DropdownPrices[Settings.PreferredPrice]
	if not ItemPriceData[PreferredPrice] then return end
	ItemData.sellPriceTTC = tonumber(ItemPriceData[PreferredPrice])
	ItemData.stackSellPriceTTC = ItemData.sellPriceTTC * ItemData.stackCount
	if ItemData.sellPriceTTC < ItemData.sellPrice and Settings.IgnoreBelowVendor then return end --if less than ESO price
	if ItemData.sellPriceTTC < Settings.RequiredValue and Settings.MinimumReq then return end --if less than RequiredValue
	--round and format
	local Price_unit_TTC = RoundAndFormat(ItemData.sellPriceTTC)
	local Price_stack_TTC =  RoundAndFormat(ItemData.stackSellPriceTTC)
	local Price_unit_ESO =  RoundAndFormat(ItemData.sellPrice)
	local Price_stack_ESO =  RoundAndFormat(ItemData.stackSellPrice)
	local NewPriceText = ""
	local PriceFormats = {
		["Stack and Unit"] = Colors.Orange .. Price_stack_TTC .. "|r " .. CoinIcon .. "\n" .. Colors.White .. "@|r" .. Colors.Dark_Orange .. Price_unit_TTC .. "|r " .. CoinIcon,
		["Stack"] = Colors.Orange .. Price_stack_TTC.. "|r " .. CoinIcon,
		["Unit"] = Colors.Dark_Orange .. Price_unit_TTC .. "|r " .. CoinIcon,
		["Stack (ESO and TTC)"] = Colors.White .. Price_stack_ESO .. "|r " .. CoinIcon .. "\n" .. Colors.Orange .. Price_stack_TTC .. "|r " .. CoinIcon,
		["Unit (ESO and TTC)"] = Colors.White .. Price_unit_ESO .. "|r " .. CoinIcon .. "\n" .. Colors.Dark_Orange .. Price_unit_TTC .. "|r " .. CoinIcon,
	}
	local HighlightedPriceFormats = {
		["Stack and Unit"] = Colors.Green .. Price_stack_TTC .. "|r " .. CoinIcon .. "\n" .. Colors.White .. "@|r" .. Colors.Dark_Green .. Price_unit_TTC .. "|r " .. CoinIcon,
		["Stack"] = Colors.Green .. Price_stack_TTC .. "|r " .. CoinIcon,
		["Unit"] = Colors.Dark_Green .. Price_unit_TTC .. "|r " .. CoinIcon,
		["Stack (ESO and TTC)"] = Colors.White .. Price_stack_ESO .. "|r " .. CoinIcon .. "\n" .. Colors.Green .. Price_stack_TTC .. "|r " .. CoinIcon,
		["Unit (ESO and TTC)"] = Colors.White .. Price_unit_ESO .. "|r " .. CoinIcon .. "\n" .. Colors.Dark_Green .. Price_unit_TTC .. "|r " .. CoinIcon,
	}
	local PriceToShow = Settings.PriceToShow
	if ItemData.stackCount == 1 and PriceToShow == "Stack and Unit" then PriceToShow = "Stack" end
	if Settings.HighlightReq and ItemData.sellPriceTTC >= Settings.DesiredValue then --if greater than DesiredValue
		NewPriceText = HighlightedPriceFormats[PriceToShow]
	else
		NewPriceText = PriceFormats[PriceToShow]
	end
	SellPriceControl:SetText(NewPriceText)
end

local function CheckDeal(itemLink, purchasePrice, stackCount)
    local deal = -1
	local discount = 0
	local profit = -1
    local ItemPriceData = TamrielTradeCentrePrice:GetPriceInfo(itemLink)
    if not ItemPriceData then return 2, discount, profit, 0 end
	local SuggestedPrice = ItemPriceData.SuggestedPrice or 0
    local EntryCount = ItemPriceData.EntryCount or 1
	if SuggestedPrice == 0 and ItemPriceData.Avg > 0 then --fallback to Average
		SuggestedPrice = ItemPriceData.Avg
	end
	local UnitPrice = purchasePrice / stackCount
	profit = (SuggestedPrice - UnitPrice) * stackCount
	discount = tonumber(string.format('%.2f', ((SuggestedPrice - UnitPrice) / SuggestedPrice) * 100))
	if ((discount >= 85 and EntryCount > 35) or (discount >= 70 and EntryCount > 80)) then
        deal = 5 --Excellent
	elseif ((discount >= 65 and EntryCount > 35) or (discount >= 50 and EntryCount > 80)) then
        deal = 4 --Amazing
	elseif ((discount >= 45 and EntryCount > 35) or (discount >= 30 and EntryCount > 80)) then
        deal = 3 --Great
	elseif ((discount >= 25 and EntryCount > 35) or (discount >= 10 and EntryCount > 80)) then
        deal = 2 --Good
    elseif (discount >= 0) then
        deal = 1 --OK
    else
        deal = 0 --Overpriced
    end
	return deal, discount, profit, EntryCount
end

local function ShowTTCDeal(rowControl, result)
	if not result.itemLink then return end

	local DealControl = rowControl:GetNamedChild('DealControl')
	if Settings.GuildStoreInfoToShow == "None" then 
		if DealControl then
			DealControl:SetHidden(true)
		end
		return
	end
	
	if not DealControl then
		DealControl = rowControl:CreateControl(rowControl:GetName() .. 'DealControl', CT_LABEL)
		local TimeControl = rowControl:GetNamedChild('TimeRemaining')
		local NameControl = rowControl:GetNamedChild('Name')
		TimeControl:ClearAnchors()
		TimeControl:SetAnchor(LEFT, NameControl, RIGHT, 20)
		DealControl:SetAnchor(TOPLEFT, TimeControl, BOTTOMLEFT, 0, 0)
		DealControl:SetFont('/esoui/common/fonts/univers67.otf|18|soft-shadow-thin')
	end
	local DealValue, Discount, Profit, EntryCount= CheckDeal(result.itemLink, result.purchasePrice, result.stackCount)
	if not DealValue then return end
	if DealValue > -1 then
		if Settings.GuildStoreInfoToShow == "Profit" then
			DealControl:SetText(RoundAndFormat(Profit) .. " " .. CoinIcon)
		elseif Settings.GuildStoreInfoToShow == "Discount" then
			DealControl:SetText(Discount .. '%')
		else
			DealControl:SetHidden(true)
			return
		end
		if Settings.HighlightRiskyDeals and EntryCount < Settings.RiskyDealsListingsCount then --unsure
			DealControl:SetColor(1, 0.62, 0.62, 1) 
		elseif DealValue == 0 then --overpriced
			DealControl:SetColor(1, 0, 0, 1)
		else
			local r, g, b = GetInterfaceColor(INTERFACE_COLOR_TYPE_ITEM_QUALITY_COLORS, DealValue)
			DealControl:SetColor(r, g, b, 1)
		end
		DealControl:SetHidden(false)
	else
		DealControl:SetHidden(true)
	end
end  

function Addon.InitializeGuildStoreHook(eventCode, responseType, result)
	if responseType == TRADING_HOUSE_RESULT_SEARCH_PENDING and result == TRADING_HOUSE_RESULT_SUCCESS and not GuildStoreHook1 then
		if TRADING_HOUSE.searchResultsList then
			GuildStoreHook1 = true
			if GuildStoreHook2 then
				EVENT_MANAGER:UnregisterForEvent(Addon.name, EVENT_TRADING_HOUSE_RESPONSE_RECEIVED)
			end
			local DataType = TRADING_HOUSE.searchResultsList.dataTypes[1]
			SecurePostHook(DataType, 'setupCallback', ShowTTCDeal)
		end
	elseif responseType == TRADING_HOUSE_RESULT_LISTINGS_PENDING and not GuildStoreHook2 then
		if TRADING_HOUSE.postedItemsList then
			GuildStoreHook2 = true
			if GuildStoreHook1 then
				EVENT_MANAGER:UnregisterForEvent(Addon.name, EVENT_TRADING_HOUSE_RESPONSE_RECEIVED)
			end
			local DataType2 = TRADING_HOUSE.postedItemsList.dataTypes[2]
			SecurePostHook(DataType2, 'setupCallback', ShowTTCDeal)
		end
	end
end

function Addon.InitializeDealFilter()
    local FilterBase = AwesomeGuildStore.class.FilterBase
    local ValueRangeFilterBase = AwesomeGuildStore.class.ValueRangeFilterBase
    local FILTER_ID = AwesomeGuildStore:GetFilterIds()
    local DealFilter = ValueRangeFilterBase:Subclass()
    function DealFilter:New(...) return ValueRangeFilterBase.New(self, ...) end

    function DealFilter:Initialize()
		ValueRangeFilterBase.Initialize(self, FILTER_ID.SHOW_TTC_PRICE_DEAL_FILTER or 837, FilterBase.GROUP_SERVER, {
			label = "Deal Filter", min = 1, max = 6,
			steps = {{id = 1, label = "Overpriced"}, {id = 2, label = "OK"}, {id = 3, label = "Good"}, {id = 4, label = "Great"}, {id = 5, label = "Amazing"}, {id = 6, label = "Excellent"}}
		})
		
		function DealFilter:CanFilter(subcategory) return true end
		local dealById = {}
        for i = 1, #self.config.steps do
            local step = self.config.steps[i]
			local color = i == 1 and ZO_ColorDef:New(1, 0, 0) or GetItemQualityColor(step.id - 1)
			step.color = color
			step.colorizedLabel = color:Colorize(step.label)
            dealById[step.id] = step
        end
        self.dealById = dealById
    end

    function DealFilter:FilterLocalResult(result)
        local dealValue, _, _, _ = CheckDeal(result.itemLink, result.purchasePrice, result.stackCount)
        return not ((dealValue or -5) + 1 < self.localMin or (dealValue or 5) + 1 > self.localMax)
    end

    function DealFilter:GetTooltipText(min, max)
        if (min ~= self.config.min or max ~= self.config.max) then
            local out = {}
            for id = min, max do
                local step = self.dealById[id]
                out[#out + 1] = step.colorizedLabel
            end
            return table.concat(out, ", ")
        end
        return ""
    end

	AwesomeGuildStore:RegisterFilter(DealFilter:New())
	AwesomeGuildStore:RegisterFilterFragment(AwesomeGuildStore.class.QualityFilterFragment:New(FILTER_ID.SHOW_TTC_PRICE_DEAL_FILTER or 837)) --placeholder
end

function Addon.InitializeProfitFilter()
    local FilterBase = AwesomeGuildStore.class.FilterBase
    local ValueRangeFilterBase = AwesomeGuildStore.class.ValueRangeFilterBase
    local FILTER_ID = AwesomeGuildStore:GetFilterIds()
    local ProfitFilter = ValueRangeFilterBase:Subclass()
    function ProfitFilter:New(...) return ValueRangeFilterBase.New(self, ...) end
	
    function ProfitFilter:Initialize()
        ValueRangeFilterBase.Initialize(self, FILTER_ID.SHOW_TTC_PRICE_PROFIT_FILTER or 838, FilterBase.GROUP_SERVER, {
            label = "Profit Filter", currency = CURT_MONEY, min = 1, max = 100000000, precision = 0,
            steps = { 1, 250, 500, 750, 1000, 2000, 3000, 4000, 5000, 6000, 7000, 8000, 9000, 10000, 25000, 50000, 75000, 100000, 1000000, 100000000 }
        })
        function ProfitFilter:CanFilter(subcategory) return true end
    end

    function ProfitFilter:FilterLocalResult(result)
        local _, _, profit, _ = CheckDeal(result.itemLink, result.purchasePrice, result.stackCount)
        if not profit or (profit < (self.localMin or 1)) or (profit > (self.localMax or 100000000)) then return false end
        return true
    end

	AwesomeGuildStore:RegisterFilter(ProfitFilter:New())
	AwesomeGuildStore:RegisterFilterFragment(AwesomeGuildStore.class.PriceRangeFilterFragment:New(FILTER_ID.SHOW_TTC_PRICE_PROFIT_FILTER or 838)) --placeholder
end

function Addon.InitializeAwesomeGuildStoreIntegration()
	if Settings.EnableDealFilter then Addon.InitializeDealFilter() end
	if Settings.EnableProfitFilter then Addon.InitializeProfitFilter() end
end

function Addon.InitializeToggleButton()
	local ta = {ZO_PlayerInventory, ZO_CraftBag, ZO_PlayerBank, ZO_HouseBank, ZO_GuildBank}
	local enabled = Settings.Enabled
	for i = 1, #ta do
		local button = WINDOW_MANAGER:CreateControlFromVirtual("ShowTTCPrice_TogglePriceButton_" .. tostring(i), ta[i], "ZO_DefaultButton")
		button:SetWidth(80, 28)
		if enabled then button:SetText("TTC " .. CoinIcon) else button:SetText("ESO " .. CoinIcon) end
		button:ClearAnchors()
		button:SetAnchor(BOTTOMLEFT, ta[i], TOPLEFT,0,-5)
		button:SetClickSound("Click")
		button:SetHandler("OnClicked", function() ShowTTCPrice_TogglePrices() end)
		button:SetState(BSTATE_NORMAL)
		button:SetDrawTier(2)
		table.insert(TogglePriceButtons, button)
	end
end

function Addon.Initialize()
	if Settings.EnableToggleButton then Addon.InitializeToggleButton() end --optional toggle
	--inventories
	for _, i in pairs(PLAYER_INVENTORY.inventories) do
		local ListView = i.listView
		if ListView and ListView.dataTypes and ListView.dataTypes[1] and ListView:GetName() ~= "ZO_PlayerInventoryQuest" then --(ignore quest tab)
			local DataType = ListView.dataTypes[1]
			SecurePostHook(DataType, 'setupCallback', function(control, slot)
				if SCENE_MANAGER:GetCurrentScene() ~= STABLES_SCENE then  --(ignore stables scene)
					ShowTTCPrice(control, slot)
				end
			end)
		end
	end
	--deconstruction (crafting stations)
	SecurePostHook(ZO_SmithingTopLevelDeconstructionPanelInventoryBackpack.dataTypes[1], "setupCallback", function(control, slot)
        ShowTTCPrice(control, slot)
	end)
	--deconstruction (assistant)
	SecurePostHook(ZO_UniversalDeconstructionTopLevel_KeyboardPanelInventoryBackpack.dataTypes[1], "setupCallback", function(control, slot)
		ShowTTCPrice(control, slot)
	end)
end

function Addon.OnAddOnLoaded(event, addonName)
	if addonName ~= Addon.name then return end
	EVENT_MANAGER:UnregisterForEvent(Addon.name, EVENT_ADD_ON_LOADED)
	Addon.SavedVariables = ZO_SavedVars:NewAccountWide("ShowTTCPriceVars", Addon.SV_version, GetWorldName(), SV_default)
	ZO_CreateStringId("SI_BINDING_NAME_ShowTTCPrice_PriceToggleKeybind", "Toggle TTC Price")
	Addon.SetupSettings()
	Addon.Initialize()
	if Settings.EnableInGuildStore then --guild store
		EVENT_MANAGER:RegisterForEvent(Addon.name, EVENT_TRADING_HOUSE_RESPONSE_RECEIVED, Addon.InitializeGuildStoreHook)
		if Settings.EnableAwesomeGuildStoreIntegration and AwesomeGuildStore then --AwesomeGuildStore
			AwesomeGuildStore:RegisterCallback(AwesomeGuildStore.callback.AFTER_FILTER_SETUP, Addon.InitializeAwesomeGuildStoreIntegration)
		end
	end
end

EVENT_MANAGER:RegisterForEvent(Addon.name, EVENT_ADD_ON_LOADED, Addon.OnAddOnLoaded)
